asr.dos
=======

.. automodule:: asr.dos

   
   
   .. rubric:: Functions

   
   .. autofunction:: collect_data
   .. autofunction:: plot
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   